@@ -101,6 +101,7 @@ OC.L10N.register(
     "Create new board" : "Vytvořit novou tabuli",
     "new board" : "nová tabule",
     "Select the board to link to a project" : "Vyberte tabuli kterou propojit s projektem",
+    "Search by board title" : "Hledat podle názvu tabule",
     "Select board" : "Vybrat tabuli",
     "Select the card to link to a project" : "Vyberte kartu kterou propojit s projektem",
     "Select a board" : "Vybrat tabuli",
@@ -126,6 +127,7 @@ OC.L10N.register(
     "Next 7 days" : "Příštích 7 dnů",
     "Next 30 days" : "Příštích 30 dnů",
     "No due date" : "Žádný termín",
+    "Clear filter" : "Vyčistit filtr",
     "Show archived cards" : "Zobrazit archivované karty",
     "Toggle compact mode" : "Vyp/zap. kompaktní režim",
     "Details" : "Podrobnosti",
@@ -153,7 +155,7 @@ OC.L10N.register(
     "Edit" : "Upravit",
     "Add a new tag" : "Přidat nový štítek",
     "title and color value must be provided" : "je třeba zadat nadpis a zvolit barvu",
-    "Title" : "Nadpisu",
+    "Title" : "Nadpis",
     "Members" : "Členové",
     "Add this attachment" : "Přidat tuto přílohu",
     "Delete Attachment" : "Smazat přílohu",
@@ -189,6 +191,8 @@ OC.L10N.register(
     "(circle)" : "(okruh)",
     "seconds ago" : "před několika sekundami",
     "Assign to me" : "Přiřadit mě",
+    "Unarchive card" : "Zrušit archivaci karty",
+    "Archive card" : "Archivovat kartu",
     "Delete card" : "Smazat kartu",
     "Move card" : "Přesunout kartu",
     "Card details" : "Podrobnosti o kartě",
@@ -196,22 +200,21 @@ OC.L10N.register(
     "Select a stack" : "Vybrat sloupec",
     "All boards" : "Všechny tabule",
     "Archived boards" : "Archivované tabule",
-    "Shared boards" : "Sdílené tabule",
-    "Settings" : "Nastavení",
+    "Shared with you" : "Sdíleno s vámi",
     "Limit deck usage of groups" : "Omezit využití deck na skupiny",
     "Limiting Deck will block users not part of those groups from creating their own boards. Users will still be able to work on boards that have been shared with them." : "Omezení nastavené pro Deck brání uživatelům, kteří nejsou součástí těchto skupin, ve vytváření vlastních tabulí. Nicméně i tak ale pořád budou moci pracovat na tabulích, které jsou jim nasdíleny.",
+    "Settings" : "Nastavení",
     "New board title" : "Název nové tabule",
-    "Share" : "Sdílet",
-    "Options" : "Volby",
     "Edit board" : "Upravit tabuli",
+    "Clone board " : "Klonovat tabuli ",
+    "Unarchive board " : "Vrátit tabuli zpět z archivu ",
+    "Archive board " : "Archivovat tabuli ",
+    "Delete board " : "Smazat tabuli",
+    "Board details" : "Podrobnosti o desce",
+    "Board {0} deleted" : "Tabule {0} smazána",
     "An error occurred" : "Došlo k chybě",
-    "Clone board" : "Klonovat tabuli",
-    "Archive board" : "Archivovat tabuli",
-    "Unarchive board" : "Vrátit tabuli zpět z archivu",
     "Are you sure you want to delete the board {title}? This will delete all the data of this board." : "Opravdu chcete tabuly {title} smazat? Toto smaže veškerá data této tabule.",
     "Delete the board?" : "Smazat tabuli?",
-    "Delete board" : "Smazat tabuli",
-    "Board details" : "Podrobnosti o desce",
     "Link to a board" : "Propojit s tabulí",
     "Link to a card" : "Propojit s kartou",
     "Something went wrong" : "Něco se pokazilo",
