@@ -31,6 +31,8 @@ OC.L10N.register(
     "Add a new stack" : "Agregar una nueva pila",
     "Add card" : "Agregar tarjeta",
     "Edit" : "Editar",
+    "Title" : "Título",
+    "Members" : "Miembros",
     "Due date" : "Fecha de vencimiento",
     "Remove due date" : "Eliminar fecha de expiración",
     "Description" : "Descripción",
@@ -45,14 +47,10 @@ OC.L10N.register(
     "(group)" : "(grupo)",
     "seconds ago" : "hace segundos",
     "Archived boards" : "Tableros archivados",
-    "Shared boards" : "Tableros compartidos",
+    "Shared with you" : "Compartido con usted",
     "Settings" : "Configuraciones ",
     "New board title" : "Nuevo título del tablero",
-    "Share" : "Compartir",
     "Edit board" : "Editar el tablero",
-    "Archive board" : "Archivar tablero",
-    "Unarchive board" : "Desarchivar tablero",
-    "Delete board" : "Borrar tableros",
     "Board details" : "Detalles del tablero"
 },
 "nplurals=2; plural=(n != 1);");
