@@ -17,6 +17,7 @@ OC.L10N.register(
     "Can share" : "Can share",
     "Delete" : "Kustuta",
     "Edit" : "Redigeeri",
+    "Title" : "Pealkiri",
     "Due date" : "Tähtaeg",
     "Description" : "Kirjeldus",
     "Comments" : "Kommentaarid",
@@ -27,8 +28,8 @@ OC.L10N.register(
     "Update" : "Uuenda",
     "(group)" : "(grupp)",
     "seconds ago" : "sekundit tagasi",
+    "Shared with you" : "Sinuga jagatud",
     "Settings" : "Seaded",
-    "Share" : "Jaga",
     "An error occurred" : "Tekkis tõrge"
 },
 "nplurals=2; plural=(n != 1);");
