@@ -12,6 +12,16 @@ OC.L10N.register(
     "You have removed {acl} from the board {board}" : "הסרת את {acl} מהלוח {board}",
     "{user} has removed {acl} from the board {board}" : "בוצעה הסרה של {acl} מהלוח {board} על ידי {user}",
     "You have renamed the board {before} to {board}" : "שינית את שם הלוח {before} לשם {board}",
+    "{user} has renamed the board {before} to {board}" : "השם של הלוח {before} השתנה לשם {board} על ידי {user}",
+    "You have archived the board {board}" : "העברת את הלוח {board} לארכיון",
+    "{user} has archived the board {before}" : "הארכיון {before} הועבר לארכיון על ידי {user}",
+    "You have unarchived the board {board}" : "הוצאת את הלוח {board} מהארכיון",
+    "{user} has unarchived the board {before}" : "הלוח {before} הוצא מהארכיון על ידי {user}",
+    "You have created a new stack {stack} on board {board}" : "יצרת ערימה חדשה {stack} בלוח {board}",
+    "{user} has created a new stack {stack} on board {board}" : "נוצרה ערימה חדשה {stack} בלוח {board} על ידי {user}",
+    "You have renamed stack {before} to {stack} on board {board}" : "שינית את שם הערימה {before} לשם {stack} בלוח {board}",
+    "You have removed the due date of card {card}" : "הסרת את מועד היעד מהכרטיס {card}",
+    "{user} has removed the due date of card {card}" : "מועד היעד של הכרטיס {card} הוסר על ידי {user}",
     "You have commented on card {card}" : "הגבת על הכרטיס {cart}",
     "{user} has commented on card {card}" : "נוספה תגובה מאת {user} על הכרטיס {card}",
     "A <strong>card description</strong> inside the Deck app has been changed" : "<strong>תיאור של כרטיס</strong> בתוך יישומון החבילה נערך",
@@ -19,7 +29,11 @@ OC.L10N.register(
     "Changes in the <strong>Deck app</strong>" : "שינויים ל<strong>יישומון החבילה</strong>",
     "A <strong>comment</strong> was created on a card" : "נוצרה <strong>הערה</strong> על כרטיס",
     "Personal" : "אישי",
+    "The card \"%s\" on \"%s\" has been assigned to you by %s." : "הכרטיס \"%s\" שב־„%s” הוקצה אליך על ידי %s.",
+    "{user} has assigned the card \"%s\" on \"%s\" to you." : "הכרטיס „%s” שב„%s” הוקצה לך על ידי {user}.",
     "The card \"%s\" on \"%s\" has reached its due date." : "הכרטיס „%s” שתחת „%s” הגיע למועד התפוגה שלו.",
+    "%s has mentioned you in a comment on \"%s\"." : "אוזכרת על ידי %s בתגובה על „%s”.",
+    "{user} has mentioned you in a comment on \"%s\"." : "אוזכרת על ידי {user} בתגובה על „%s”.",
     "The board \"%s\" has been shared with you by %s." : "הלוח „%s” שותף אתך על ידי %s.",
     "{user} has shared the board %s with you." : "הלוח %s שותף אתך על ידי {user}",
     "No data was provided to create an attachment." : "לא סופקו נתונים ליצירת קובץ מצורף",
@@ -47,6 +61,7 @@ OC.L10N.register(
     "Create new board" : "יצירת לוח חדש",
     "new board" : "לוח חדש",
     "Select the board to link to a project" : "נא לבחור את הלוח לקישור למיזם",
+    "Search by board title" : "חיפוש לפי כותרת לו",
     "Select board" : "בחירת לוח",
     "Select the card to link to a project" : "נא לבחור את הכרטיס לקישור למיזם",
     "Select a board" : "נא לבחור לוח",
@@ -72,6 +87,7 @@ OC.L10N.register(
     "Next 7 days" : "ב־7 הימים הבאים",
     "Next 30 days" : "ב־30 הימים הבאים",
     "No due date" : "ללא תאריך יעד",
+    "Clear filter" : "מחיקת מסנן",
     "Show archived cards" : "הצגת כרטיסים בארכיון",
     "Toggle compact mode" : "החלפת מצב חסכוני",
     "Details" : "פרטים",
@@ -135,28 +151,30 @@ OC.L10N.register(
     "(circle)" : "(מעגל)",
     "seconds ago" : "לפני מספר שניות",
     "Assign to me" : "הקצאה אלי",
+    "Unarchive card" : "הוצאת הכרטיס מהארכיון",
+    "Archive card" : "העברת כרטיס לארכיון",
     "Delete card" : "מחיקת כרטיס לארכיון",
     "Move card" : "העברת כרטיס",
     "Card details" : "פרטי הכרטיס",
+    "Move card to another board" : "העברת כרטיס ללוח אחר",
     "Select a stack" : "בחירת ערימה",
     "All boards" : "כל הלוחות",
     "Archived boards" : "לוחות שנשמרו בארכיון",
-    "Shared boards" : "לוחות משותפים",
-    "Settings" : "הגדרות",
+    "Shared with you" : "משותף אתך",
     "Limit deck usage of groups" : "הגבלת השימוש בחבילה לקבוצות",
     "Limiting Deck will block users not part of those groups from creating their own boards. Users will still be able to work on boards that have been shared with them." : "הגבלת חבילה תחסום משתמשים שאינם חלק מקבוצות אלו מיצירת לוחות משלהם. משתמשים עדיין יוכלו לעבור על לוחות ששותפו אתם.",
+    "Settings" : "הגדרות",
     "New board title" : "כותרת לוח חדשה",
-    "Share" : "שיתוף",
-    "Options" : "אפשרויות",
     "Edit board" : "עריכת לוח",
+    "Clone board " : "שכפול לוח",
+    "Unarchive board " : "הוצאת הלוח מהארכיון",
+    "Archive board " : "העברת הלוח לארכיון",
+    "Delete board " : "מחיקת לוח",
+    "Board details" : "פרטי לוח",
+    "Board {0} deleted" : "הלוח {0} נמחק",
     "An error occurred" : "אירעה שגיאה",
-    "Clone board" : "שכפול לוח",
-    "Archive board" : "העברת לוח לארכיון",
-    "Unarchive board" : "הוצאת ארכיון מהלוח",
     "Are you sure you want to delete the board {title}? This will delete all the data of this board." : "למחוק את הלוח {title}? פעולה זו תמחק את כל הנתונים של הלוח הזה.",
     "Delete the board?" : "למחוק את הלוח הזה?",
-    "Delete board" : "מחיקת לו",
-    "Board details" : "פרטי לוח",
     "Link to a board" : "קישור ללוח",
     "Link to a card" : "קישור לכרטיס",
     "Something went wrong" : "משהו השתבש",
