@@ -144,21 +144,18 @@ OC.L10N.register(
     "Update" : "更新",
     "(group)" : "(グループ)",
     "seconds ago" : "数秒前",
+    "Unarchive card" : "カードのアーカイブを解除する",
+    "Archive card" : "カードをアーカイブ",
     "Delete card" : "カードを削除する",
     "Move card" : "カードの移動",
     "Archived boards" : "アーカイブ済みのボード",
-    "Shared boards" : "共有ボード",
-    "Settings" : "設定",
+    "Shared with you" : "あなたと共有済み",
     "Limiting Deck will block users not part of those groups from creating their own boards. Users will still be able to work on boards that have been shared with them." : "デッキ作成制限は、設定したグループに非所属のユーザーがボードを作成できないようにします。非所属ユーザーは共有されているボードでのみ作業できます。",
+    "Settings" : "設定",
     "New board title" : "新しいボードのタイトル",
-    "Share" : "共有",
-    "Options" : "オプション",
     "Edit board" : "ボードを編集",
-    "An error occurred" : "エラーが発生しました",
-    "Archive board" : "ボードをアーカイブ",
-    "Unarchive board" : "ボードのアーカイブを解除",
-    "Delete board" : "ボードを削除",
     "Board details" : "ボードの詳細",
+    "An error occurred" : "エラーが発生しました",
     "Link to a board" : "ボードへのリンク",
     "Maximum file size of {size} exceeded" : "最大ファイルサイズ（{size}）を超えています"
 },
