@@ -31,6 +31,8 @@ OC.L10N.register(
     "Add a new stack" : "დასტის დამატება",
     "Add card" : "ბარათის დამატება",
     "Edit" : "შეცვლა",
+    "Title" : "სათაური",
+    "Members" : "წევრები",
     "Due date" : "დროისთვის",
     "Remove due date" : "მოაშორეთ დანიშნულების დრო",
     "Description" : "აღწერა",
@@ -45,14 +47,10 @@ OC.L10N.register(
     "(group)" : "(ჯგუფი)",
     "seconds ago" : "წამის წინ",
     "Archived boards" : "არქივირებული დაფები",
-    "Shared boards" : "გაზიარებული დაფები",
+    "Shared with you" : "გაზიარებული თქვენთან",
     "Settings" : "პარამეტრები",
     "New board title" : "ახალი დაფის სახელი",
-    "Share" : "გაზიარება",
     "Edit board" : "დაფის შეცვლა",
-    "Archive board" : "დაფის არქივირება",
-    "Unarchive board" : "დაფის ამოღება",
-    "Delete board" : "დაფის გაუქმება",
     "Board details" : "დაფის დეტალები"
 },
 "nplurals=2; plural=(n!=1);");
