@@ -14,7 +14,7 @@ OC.L10N.register(
     "Title" : "ಶೀರ್ಷಿಕೆ",
     "Modified" : "﻿ಬದಲಾಯಿಸಿದ",
     "Save" : "﻿ಉಳಿಸಿ",
-    "Settings" : "ಆಯ್ಕೆ",
-    "Share" : "﻿ಹಂಚಿಕೊಳ್ಳಿ"
+    "Shared with you" : "Shared with you",
+    "Settings" : "ಆಯ್ಕೆ"
 },
 "nplurals=2; plural=(n > 1);");
