@@ -98,6 +98,7 @@ OC.L10N.register(
     "Create new board" : "Sukurti naują lentą",
     "new board" : "nauja lenta",
     "Select the board to link to a project" : "Pasirinkite lentą, kurią susieti su projektu",
+    "Search by board title" : "Ieškoti pagal lentos pavadinimą",
     "Select board" : "Pasirinkti lentą",
     "Select the card to link to a project" : "Pasirinkite kortelę, kurią susieti su projektu",
     "Select a board" : "Pasirinkite lentą",
@@ -122,6 +123,7 @@ OC.L10N.register(
     "Next 7 days" : "Artimiausios 7 dienos",
     "Next 30 days" : "Artimiausios 30 dienų",
     "No due date" : "Be galutinio termino",
+    "Clear filter" : "Išvalyti filtrą",
     "Show archived cards" : "Rodyti archyvuotas korteles",
     "Toggle compact mode" : "Perjungti kompaktišką veikseną",
     "Details" : "Išsamiau",
@@ -184,26 +186,28 @@ OC.L10N.register(
     "(circle)" : "(ratas)",
     "seconds ago" : "prieš keletą sekundžių",
     "Assign to me" : "Priskirti sau",
+    "Unarchive card" : "Išarchyvuoti kortelę",
+    "Archive card" : "Archyvuoti kortelę",
     "Delete card" : "Ištrinti kortelę",
     "Move card" : "Perkelti kortelę",
     "Card details" : "Išsamiau apie kortelę",
+    "Move card to another board" : "Perkelti kortelę į kitą lentą",
     "Select a stack" : "Pasirinkti dėklą",
     "All boards" : "Visos lentos",
     "Archived boards" : "Archyvuotos lentos",
-    "Shared boards" : "Bendrinamos lentos",
+    "Shared with you" : "Bendrinama su jumis",
     "Settings" : "Nustatymai",
     "New board title" : "Naujos lentos pavadinimas",
-    "Share" : "Bendrinti",
-    "Options" : "Parinktys",
     "Edit board" : "Taisyti lentą",
+    "Clone board " : "Dubliuoti lentą ",
+    "Unarchive board " : "Išarchyvuoti lentą ",
+    "Archive board " : "Archyvuoti lentą ",
+    "Delete board " : "Ištrinti lentą ",
+    "Board details" : "Išsamiau apie lentą",
+    "Board {0} deleted" : "Lenta {0} ištrinta",
     "An error occurred" : "Įvyko klaida",
-    "Clone board" : "Dubliuoti lentą",
-    "Archive board" : "Archyvuoti lentą",
-    "Unarchive board" : "Išarchyvuoti lentą",
     "Are you sure you want to delete the board {title}? This will delete all the data of this board." : "Ar tikrai norite ištrinti lentą, pavadinimu {title}? Tai ištrins visus šios lentos duomenis.",
     "Delete the board?" : "Ištrinti lentą?",
-    "Delete board" : "Ištrinti lentą",
-    "Board details" : "Išsamiau apie lentą",
     "Link to a board" : "Susieti su lenta",
     "Link to a card" : "Susieti su kortele",
     "Something went wrong" : "Kažkas nutiko",
