@@ -11,7 +11,7 @@ OC.L10N.register(
     "Comments" : "تبصرې",
     "Modified" : "د بدلون نېټه",
     "Save" : "ساتل",
-    "Settings" : "سمونې",
-    "Share" : "شریکول"
+    "Shared with you" : "تاسې سره شريک شوي",
+    "Settings" : "سمونې"
 },
 "nplurals=2; plural=(n != 1);");
