@@ -27,7 +27,7 @@ OC.L10N.register(
     "Update" : "Actualizare",
     "(group)" : "(grup)",
     "seconds ago" : "secunde în urmă",
-    "Settings" : "Setări",
-    "Share" : "Partajează"
+    "Shared with you" : "Partajat cu tine",
+    "Settings" : "Setări"
 },
 "nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));");
