@@ -20,7 +20,7 @@ OC.L10N.register(
     "Save" : "සුරකින්න",
     "Update" : "යාවත්කාල කිරීම",
     "seconds ago" : "තත්පරයන්ට පෙර",
-    "Settings" : "සැකසුම්",
-    "Share" : "බෙදා හදා ගන්න"
+    "Shared with you" : "Shared with you",
+    "Settings" : "සැකසුම්"
 },
 "nplurals=2; plural=(n != 1);");
