@@ -1,7 +1,7 @@
 OC.L10N.register(
     "deck",
     {
-    "You have created a new board {board}" : "Vytvorili ste nová nástenku {board}",
+    "You have created a new board {board}" : "Vytvorili ste novú nástenku {board}",
     "{user} has created a new board {board}" : "Používateľ {user} vytvoril novú nástenku {board}",
     "You have deleted the board {board}" : "Vymazali ste nástenku {board}",
     "{user} has deleted the board {board}" : "Používateľ {user} vymazal nástenku {board}",
@@ -17,42 +17,42 @@ OC.L10N.register(
     "{user} has archived the board {before}" : "Používateľ {user} archivoval nástenku {board}",
     "You have unarchived the board {board}" : "Zrušili ste archiváciu nástenky {board}",
     "{user} has unarchived the board {before}" : "Používateľ {user} zrušil archiváciu nástenky {before}",
-    "You have created a new stack {stack} on board {board}" : "Vytvorili ste nový stoh {stack} na nástenke {board}",
-    "{user} has created a new stack {stack} on board {board}" : "Používateľ {user} vytvoril nový stoh {stack} na nástenke {board}",
-    "You have renamed stack {before} to {stack} on board {board}" : "Premenovali ste stoh {before} na {stack} na nástenke {board}",
-    "{user} has renamed stack {before} to {stack} on board {board}" : "Používateľ {user} premenoval stoh {before} na {stack} na nástenke {board}",
-    "You have deleted stack {stack} on board {board}" : "Vymazali ste stoh {stack} z nástenky {board}",
-    "{user} has deleted stack {stack} on board {board}" : "Používateľ {user} vymazal stoh {stack} z nástenky {board}",
-    "You have created card {card} in stack {stack} on board {board}" : "Vytvorili ste kartu {card} v stohu {stack} na nástenke {board}",
-    "{user} has created card {card} in stack {stack} on board {board}" : "Používateľ {user} vytvoril kartu {card} v stohu {stack} na nástenke {board}",
-    "You have deleted card {card} in stack {stack} on board {board}" : "Vymazali ste kartu {card} v stohu {stack} z nástenky {board}",
-    "{user} has deleted card {card} in stack {stack} on board {board}" : "Používateľ {user} vymazal kartu {card} v stohu {stack} z nástenky {board}",
+    "You have created a new stack {stack} on board {board}" : "Vytvorili ste nový stĺpec {stack} na nástenke {board}",
+    "{user} has created a new stack {stack} on board {board}" : "Používateľ {user} vytvoril nový stĺpec {stack} na nástenke {board}",
+    "You have renamed stack {before} to {stack} on board {board}" : "Premenovali ste stĺpec {before} na {stack} na nástenke {board}",
+    "{user} has renamed stack {before} to {stack} on board {board}" : "Používateľ {user} premenoval stĺpec {before} na {stack} na nástenke {board}",
+    "You have deleted stack {stack} on board {board}" : "Vymazali ste stĺpec {stack} z nástenky {board}",
+    "{user} has deleted stack {stack} on board {board}" : "Používateľ {user} vymazal stĺpec {stack} z nástenky {board}",
+    "You have created card {card} in stack {stack} on board {board}" : "Vytvorili ste kartu {card} v stĺpci {stack} na nástenke {board}",
+    "{user} has created card {card} in stack {stack} on board {board}" : "Používateľ {user} vytvoril kartu {card} v stĺpci {stack} na nástenke {board}",
+    "You have deleted card {card} in stack {stack} on board {board}" : "Vymazali ste kartu {card} v stĺpci {stack} z nástenky {board}",
+    "{user} has deleted card {card} in stack {stack} on board {board}" : "Používateľ {user} vymazal kartu {card} v stĺpci {stack} z nástenky {board}",
     "You have renamed the card {before} to {card}" : "Premenovali ste kartu {before} na {card}",
     "{user} has renamed the card {before} to {card}" : "Používateľ {user} premenoval kartu {before} na {card}",
-    "You have added a description to card {card} in stack {stack} on board {board}" : "Pridali ste popis ku karte {card} v stohu {stack} na nástenke {board}",
-    "{user} has added a description to card {card} in stack {stack} on board {board}" : "Používateľ {user} pridal popis ku karte {card} v stohu {stack} na nástenke {board}",
-    "You have updated the description of card {card} in stack {stack} on board {board}" : "Aktualizovali ste popis v karte {card} v stohu {stack} na nástenke {board}",
-    "{user} has updated the description of the card {card} in stack {stack} on board {board}" : "Používateľ {user} aktualizoval popis karty {card} v stohu {stack} na nástenke {board}",
-    "You have archived card {card} in stack {stack} on board {board}" : "Archivovali ste kartu {card} v stohu {stack} na nástenke {board}",
-    "{user} has archived card {card} in stack {stack} on board {board}" : "Používateľ {user} archivoval kartu {card} v stohu {stack} na nástenke {board}",
-    "You have unarchived card {card} in stack {stack} on board {board}" : "Zrušili ste archiváciu karty {card} v stohu {stack} na nástenke {board}",
-    "{user} has unarchived card {card} in stack {stack} on board {board}" : "Používateľ {user} zrušil archiváciu karty {card} v stohu {stack} na nástenke {board}",
+    "You have added a description to card {card} in stack {stack} on board {board}" : "Pridali ste popis ku karte {card} v stĺpci {stack} na nástenke {board}",
+    "{user} has added a description to card {card} in stack {stack} on board {board}" : "Používateľ {user} pridal popis ku karte {card} v stĺpci {stack} na nástenke {board}",
+    "You have updated the description of card {card} in stack {stack} on board {board}" : "Aktualizovali ste popis v karte {card} v stĺpci {stack} na nástenke {board}",
+    "{user} has updated the description of the card {card} in stack {stack} on board {board}" : "Používateľ {user} aktualizoval popis karty {card} v stĺpci {stack} na nástenke {board}",
+    "You have archived card {card} in stack {stack} on board {board}" : "Archivovali ste kartu {card} v stĺpci {stack} na nástenke {board}",
+    "{user} has archived card {card} in stack {stack} on board {board}" : "Používateľ {user} archivoval kartu {card} v stĺpci {stack} na nástenke {board}",
+    "You have unarchived card {card} in stack {stack} on board {board}" : "Zrušili ste archiváciu karty {card} v stĺpci {stack} na nástenke {board}",
+    "{user} has unarchived card {card} in stack {stack} on board {board}" : "Používateľ {user} zrušil archiváciu karty {card} v stĺpci {stack} na nástenke {board}",
     "You have removed the due date of card {card}" : "Odobrali ste termín dokončenia z karty {card}",
     "{user} has removed the due date of card {card}" : "Používateľ {user} odobral termín dokončenia z karty {card}",
     "You have set the due date of card {card} to {after}" : "Nastavili ste termín dokončenia pre kartu {card} na {after}",
     "{user} has set the due date of card {card} to {after}" : "Používateľ {user} nastavil termín dokončenia karty {card} na {after}",
     "You have updated the due date of card {card} to {after}" : "Zmenili ste termín dokončenia karty {card} na {after}",
     "{user} has updated the due date of card {card} to {after}" : "Používateľ {user} aktualizoval termín dokončenia karty {card} na {after}",
-    "You have added the tag {label} to card {card} in stack {stack} on board {board}" : "Pridali ste štítok {label} ku karte {card} v stohu {stack} na nástenke {board}",
-    "{user} has added the tag {label} to card {card} in stack {stack} on board {board}" : "Používateľ {user} pridal štítok {label} ku karte {card} v stohu {stack} na nástenke {board}",
-    "You have removed the tag {label} from card {card} in stack {stack} on board {board}" : "Odobrali ste štítok {label} z karty {card} v stohu {stack} na nástenke {board}",
-    "{user} has removed the tag {label} from card {card} in stack {stack} on board {board}" : "Používateľ {user} odobral štítok {label} z karty {card} v stohu {stack} na nástenke {board}",
+    "You have added the tag {label} to card {card} in stack {stack} on board {board}" : "Pridali ste štítok {label} ku karte {card} v stĺpci {stack} na nástenke {board}",
+    "{user} has added the tag {label} to card {card} in stack {stack} on board {board}" : "Používateľ {user} pridal štítok {label} ku karte {card} v stĺpci {stack} na nástenke {board}",
+    "You have removed the tag {label} from card {card} in stack {stack} on board {board}" : "Odobrali ste štítok {label} z karty {card} v stĺpci {stack} na nástenke {board}",
+    "{user} has removed the tag {label} from card {card} in stack {stack} on board {board}" : "Používateľ {user} odobral štítok {label} z karty {card} v stĺpci {stack} na nástenke {board}",
     "You have assigned {assigneduser} to card {card} on board {board}" : "Priradili ste používateľa {assigneduser} ku karte {card} na nástenke {board}",
     "{user} has assigned {assigneduser} to card {card} on board {board}" : "Používateľ {user} priradil používateľa {assigneduser} ku karte {card} na nástenke {board}",
     "You have unassigned {assigneduser} from card {card} on board {board}" : "Vyradili ste priradenie používateľa {assigneduser} z karty {card} na nástenke {board}",
     "{user} has unassigned {assigneduser} from card {card} on board {board}" : "Používateľ {user} vyradil používateľa {assigneduser} z karty {card} na nástenke {board}",
-    "You have moved the card {card} from stack {stackBefore} to {stack}" : "Presunuli ste kartu {card} zo stohu {stackBefore} do stohu {stack}",
-    "{user} has moved the card {card} from stack {stackBefore} to {stack}" : "Používateľ {user} presunul kartu {card} zo stohu {stackBefore} do stohu {stack}",
+    "You have moved the card {card} from stack {stackBefore} to {stack}" : "Presunuli ste kartu {card} zo stĺpca {stackBefore} do stĺpca {stack}",
+    "{user} has moved the card {card} from stack {stackBefore} to {stack}" : "Používateľ {user} presunul kartu {card} zo stĺpca {stackBefore} do stĺpca {stack}",
     "You have added the attachment {attachment} to card {card}" : "Pridali ste prílohu {attachment} ku karte {card}",
     "{user} has added the attachment {attachment} to card {card}" : "Používateľ {user} pridal prílohu {attachment} ku karte {card}",
     "You have updated the attachment {attachment} on card {card}" : "Aktualizovali ste prílohu {attachment} na karte {card}",
@@ -101,6 +101,7 @@ OC.L10N.register(
     "Create new board" : "Vytvoriť novú nástenku",
     "new board" : "nová nástenka",
     "Select the board to link to a project" : "Vybrať nástenku na vytvorenie odkazu ku projektu",
+    "Search by board title" : "Vyhľadávanie podľa názvu nástenky",
     "Select board" : "Vybrať nástenku",
     "Select the card to link to a project" : "Vyberte kartu, ktorú chcete prepojiť s projektom",
     "Select a board" : "Vyberte nástenku",
@@ -126,6 +127,7 @@ OC.L10N.register(
     "Next 7 days" : "Následujúcich 7 dní",
     "Next 30 days" : "Následujúcich 30 dní",
     "No due date" : "Bez termínu",
+    "Clear filter" : "Vyčistiť filter",
     "Show archived cards" : "Zobraziť archivované karty",
     "Toggle compact mode" : "Vyp/zap. kompaktný režim",
     "Details" : "Podrobnosti",
@@ -146,13 +148,15 @@ OC.L10N.register(
     "Can share" : "Môže sprístupniť",
     "Can manage" : "Môže spravovať",
     "Delete" : "Zmazať",
-    "Add a new stack" : "Pridať nový stoh",
+    "Add a new stack" : "Pridať nový stĺpec",
     "Delete list" : "Vymazať zoznam",
     "Add card" : "Pridať kartu",
     "Add a new card" : "Pridať novú kartu",
     "Edit" : "Upraviť",
     "Add a new tag" : "Pridať nový štítok",
     "title and color value must be provided" : "je potrebné zadať nadpis a vybrať farbu",
+    "Title" : "Názov",
+    "Members" : "Členovia",
     "Add this attachment" : "Pridať túto prílohu",
     "Delete Attachment" : "Odstrániť prílohu",
     "Restore Attachment" : "Obnoviť prílohu",
@@ -187,6 +191,8 @@ OC.L10N.register(
     "(circle)" : "(okruh)",
     "seconds ago" : "pred niekoľkými sekundami",
     "Assign to me" : "Priradiť mne",
+    "Unarchive card" : "Zrušiť archiváciu karty",
+    "Archive card" : "Archivovať kartu",
     "Delete card" : "Zmazať kartu",
     "Move card" : "Presunúť kartu",
     "Card details" : "Podrobnosti o karte",
@@ -194,22 +200,21 @@ OC.L10N.register(
     "Select a stack" : "Vybrať stĺpec",
     "All boards" : "Všetky nástenky",
     "Archived boards" : "Archivované nástenky",
-    "Shared boards" : "Sprístupnené nástenky",
-    "Settings" : "Nastavenia",
+    "Shared with you" : "Vám sprístupnené",
     "Limit deck usage of groups" : "Obmedziť použitie Deck na skupiny",
     "Limiting Deck will block users not part of those groups from creating their own boards. Users will still be able to work on boards that have been shared with them." : "Obmedzenie Násteniek bráni používateľom, ktorí nie sú súčasťou týchto skupín, aby si vytvárali vlastné nástenky. Môžu však stále pracovať na nástenkách, ktoré im niekto sprístupní.",
+    "Settings" : "Nastavenia",
     "New board title" : "Názov novej nástenky",
-    "Share" : "Sprístupňovať",
-    "Options" : "Možnosti",
     "Edit board" : "Upraviť nástenku",
+    "Clone board " : "Zdvojiť nástenku",
+    "Unarchive board " : "Zrušiť archiváciu nástenky",
+    "Archive board " : "Archivovať nástenku",
+    "Delete board " : "Zmazať nástenku",
+    "Board details" : "Podrobnosti o nástenke",
+    "Board {0} deleted" : "Nástenka {0} vymazaná",
     "An error occurred" : "Vyskytla sa chyba",
-    "Clone board" : "Duplikovať nástenku",
-    "Archive board" : "Archivovať nástenku",
-    "Unarchive board" : "Vybrať nástenku z archívu",
     "Are you sure you want to delete the board {title}? This will delete all the data of this board." : "Naozaj chcete chcete vymazať nástenku {title}? Toto zmaže všetky údaje o tejto nástenke.",
     "Delete the board?" : "Vymazať nástenku?",
-    "Delete board" : "Zmazať nástenku",
-    "Board details" : "Podrobnosti o nástenke",
     "Link to a board" : "Odkaz na nástenku",
     "Link to a card" : "Prepojiť s kartou",
     "Something went wrong" : "Niečo sa pokazilo",
