@@ -94,10 +94,12 @@ OC.L10N.register(
     "Could not write file to disk" : "Ni mogoče zapisati datoteke na disk",
     "A PHP extension stopped the file upload" : "Razširitev PHP onemogoča pošiljanje datoteke",
     "No file uploaded or file size exceeds maximum of %s" : "Ali ni poslane datoteke ali pa velikost datoteke presega omejitev %s",
+    "Personal planning and team project organization" : "Osebno načrtovanje nalog in organizacija skupinskih projektov",
     "Deck is a kanban style organization tool aimed at personal planning and project organization for teams integrated with Nextcloud.\n\n\n- 📥 Add your tasks to cards and put them in order\n- 📄 Write down additional notes in markdown\n- 🔖 Assign labels for even better organization\n- 👥 Share with your team, friends or family\n- 📎 Attach files and embed them in your markdown description\n- 💬 Discuss with your team using comments\n- ⚡ Keep track of changes in the activity stream\n- 🚀 Get your project organized" : "Program Deck je orodje za osebno načrtovanje in projektno delo v slogu kanban, ki se izvrstno vključuje v okolje Nextcloud.\n\nOrodje omogoča:\n- 📥 dodajanje in urejanje nalog\n- 📄 zapis dodatnih opomb v zapisu markdown\n- 🔖 dodeljevanje oznak za lažje urejanje in iskanje\n- 👥 souporabo v skupini, s prijatelji ali družino\n- 📎 pripenjanje in vstavljanje datotek v opise\n- 💬 opombe k posamezni nalogi\n- ⚡ sledenje spremembam in dejavnosti\n- 🚀 Organizaciji projekta",
     "Create new board" : "Ustvari novo zbirko",
     "new board" : "nova zbirka",
     "Select the board to link to a project" : "Izberite zbirko za povezavo s projektom",
+    "Search by board title" : "Išči po imenu zbirke",
     "Select board" : "Izbor zbirke",
     "Select the card to link to a project" : "Izbor naloge za povezavo do projekta",
     "Select a board" : "Izbor zbirke",
@@ -119,9 +121,11 @@ OC.L10N.register(
     "Filter by assigned user" : "Filtriraj po dodeljenem uporabniku",
     "Filter by due date" : "Filtriraj po datumu preteka",
     "Overdue" : "Preteklo",
+    "Next 24 hours" : "Naslednjih 24 ur",
     "Next 7 days" : "Naslednjih 7 dni",
     "Next 30 days" : "Naslednjih 30 dni",
     "No due date" : "Ni datuma preteka",
+    "Clear filter" : "Počisti filter",
     "Show archived cards" : "Prikaži arhivirane naloge",
     "Toggle compact mode" : "Preklopi način prikaza",
     "Details" : "Podrobnosti",
@@ -131,8 +135,10 @@ OC.L10N.register(
     "Tags" : "Oznake",
     "Deleted items" : "Izbrisani predmeti",
     "Timeline" : "Časovnica",
+    "Deleted lists" : "Izbrisani seznami",
     "Undo" : "Razveljavi",
     "Deleted cards" : "Izbrisane naloge",
+    "Share board with a user, group or circle …" : "Souporaba z uporabniki, skupinami ali krogi ...",
     "Board owner" : "Lastnik zbirke",
     "(Group)" : "(Skupina)",
     "(Circle)" : "(Krog)",
@@ -145,9 +151,11 @@ OC.L10N.register(
     "Add card" : "Dodaj nalogo",
     "Add a new card" : "Dodaj novo nalogo",
     "Edit" : "Uredi",
+    "Add a new tag" : "Dodaj novo oznako",
     "title and color value must be provided" : "navedena morata biti podatka naslova in barve",
     "Title" : "Naslov",
     "Members" : "Člani",
+    "Add this attachment" : "Dodaj prilogo",
     "Delete Attachment" : "Izbriši prilogo",
     "Restore Attachment" : "Obnovi prilogo",
     "Assign a tag to this card…" : "Dodeli oznako nalogi ...",
@@ -161,8 +169,12 @@ OC.L10N.register(
     "(Unsaved)" : "(neshranjeno)",
     "(Saving…)" : "(shranjevanje ...)",
     "Formatting help" : "Pomoč pri oblikovanju",
+    "Add Attachment" : "Dodaj prilogo",
+    "Edit description" : "Uredi opis",
+    "View description" : "Pokaži opis",
     "Attachments" : "Priloge",
     "Comments" : "Opombe",
+    "Choose attachment" : "Izbor priloge",
     "Modified" : "Spremenjeno",
     "Created" : "Ustvarjeno",
     "Upload attachment" : "Pošlji prilogo",
@@ -177,25 +189,29 @@ OC.L10N.register(
     "(circle)" : "(krog)",
     "seconds ago" : "pred nekaj sekundami",
     "Assign to me" : "Nalogo dodeli meni",
+    "Unarchive card" : "Povrni nalogo",
+    "Archive card" : "Arhiviraj nalogo",
     "Delete card" : "Izbriši nalogo",
     "Move card" : "Premakni nalogo",
     "Card details" : "Podrobnosti naloge",
+    "Move card to another board" : "Premakni nalogo v drugo zbirko",
     "Select a stack" : "Izbor paketa nalog",
     "All boards" : "Vse zbirke",
     "Archived boards" : "Arhivirane zbirke",
-    "Shared boards" : "Zbirke v souporabi",
-    "Settings" : "Nastavitve",
+    "Shared with you" : "V souporabi z vami",
     "Limiting Deck will block users not part of those groups from creating their own boards. Users will still be able to work on boards that have been shared with them." : "Omejevanje programa prepreči uporabnikom, ki niso del teh skupin, ustvarjanje novih zbirk. Uporabniki bodo še vedno lahko spreminjali zbirke, ki so jih dobili v souporabo.",
+    "Settings" : "Nastavitve",
     "New board title" : "Naslov nove zbirke",
-    "Share" : "Souporaba",
-    "Options" : "Možnosti",
     "Edit board" : "Uredi zbirko",
-    "An error occurred" : "Prišlo je do napake.",
-    "Clone board" : "Kloniraj zbirko",
-    "Archive board" : "Arhiviraj zbirko",
-    "Unarchive board" : "Povrni zbirko",
-    "Delete board" : "Izbriši zbirko",
+    "Clone board " : "Kloniraj zbirko",
+    "Unarchive board " : "Povrni zbirko iz arhiva",
+    "Archive board " : "Arhiviraj zbirko",
+    "Delete board " : "Izbriši zbirko",
     "Board details" : "Podrobnosti zbirke",
+    "Board {0} deleted" : "Zbirka {0} je izbrisana",
+    "An error occurred" : "Prišlo je do napake.",
+    "Are you sure you want to delete the board {title}? This will delete all the data of this board." : "Ali ste prepričani, da želite izbrisati zbirko »{title}«? S tem boste izbrisali tudi vse podatke zbirke.",
+    "Delete the board?" : "Ali želite izbrisati zbirko?",
     "Link to a board" : "Povezava do zbirke",
     "Link to a card" : "Povezava do naloge",
     "Something went wrong" : "Prišlo je do napake ...",
