@@ -14,6 +14,7 @@ OC.L10N.register(
     "Delete" : "Obriši",
     "Add card" : "Dodaj karticu",
     "Edit" : "Uredi",
+    "Title" : "Naslov",
     "Due date" : "Rok",
     "Description" : "Opis",
     "Attachments" : "Prilozi",
@@ -21,12 +22,11 @@ OC.L10N.register(
     "Reply" : "Odgovori",
     "Update" : "Ažuriraj",
     "seconds ago" : "pre nekoliko sekundi",
+    "Archive card" : "Arhiviraj karticu",
     "Delete card" : "Obriši karticu",
     "Move card" : "Premesti karticu",
+    "Shared with you" : "Shared with you",
     "Settings" : "Postavke",
-    "Share" : "Podeli",
-    "Edit board" : "Izmeni tablu",
-    "Archive board" : "Arhiviraj tablu",
-    "Delete board" : "Izbriši tablu"
+    "Edit board" : "Izmeni tablu"
 },
 "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
