@@ -100,6 +100,7 @@ OC.L10N.register(
     "Create new board" : "Skapa ny tavla",
     "new board" : "ny tavla",
     "Select the board to link to a project" : "Välj tavla att länka till ett projekt",
+    "Search by board title" : "Sök efter namn på tavla",
     "Select board" : "Välj tavla",
     "Select the card to link to a project" : "Välj kort att länka till ett projekt",
     "Select a board" : "Välj en tavla",
@@ -125,6 +126,7 @@ OC.L10N.register(
     "Next 7 days" : "Nästa 7 dagar",
     "Next 30 days" : "Nästa 30 dagar",
     "No due date" : "Inget slutdatum",
+    "Clear filter" : "Rensa filter",
     "Show archived cards" : "Visa arkiverade kort",
     "Toggle compact mode" : "Växla kompakt läge",
     "Details" : "Detaljer",
@@ -152,6 +154,8 @@ OC.L10N.register(
     "Edit" : "Redigera",
     "Add a new tag" : "Lägg till en ny tagg",
     "title and color value must be provided" : "titel och färg måste anges",
+    "Title" : "Titel",
+    "Members" : "Medlemmar",
     "Add this attachment" : "Lägg till denna bilaga",
     "Delete Attachment" : "Ta bort bilaga",
     "Restore Attachment" : "Återställ bilaga",
@@ -186,28 +190,25 @@ OC.L10N.register(
     "(circle)" : "(cirkel)",
     "seconds ago" : "sekunder sedan",
     "Assign to me" : "Tilldela till mig",
+    "Unarchive card" : "Avarkivera kort",
+    "Archive card" : "Arkivera kort",
     "Delete card" : "Ta bort kort",
     "Move card" : "Flytta kort",
     "Card details" : "Kortdetaljer",
+    "Move card to another board" : "Flytta kort till en annan tavla",
     "Select a stack" : "Välj en stapel",
     "All boards" : "Alla tavlor",
     "Archived boards" : "Arkiverade tavlor",
-    "Shared boards" : "Delade tavlor",
-    "Settings" : "Inställningar",
+    "Shared with you" : "Delad med dig",
     "Limit deck usage of groups" : "Begränsa användningen av grupper",
     "Limiting Deck will block users not part of those groups from creating their own boards. Users will still be able to work on boards that have been shared with them." : "Begränsa Deck blockerar användare som inte ingår i dessa grupper från att skapa egna tavlor. Användare kan fortfarande arbeta med tavlor som har delats med dem.",
+    "Settings" : "Inställningar",
     "New board title" : "Ny titel för tavla",
-    "Share" : "Dela",
-    "Options" : "Alternativ",
     "Edit board" : "Ändra tavla",
+    "Board details" : "Taveldetaljer",
     "An error occurred" : "Ett fel uppstod",
-    "Clone board" : "Kopiera tavla",
-    "Archive board" : "Arkivera tavla",
-    "Unarchive board" : "Ta bort tavlan ur arkivet",
     "Are you sure you want to delete the board {title}? This will delete all the data of this board." : "Är du säker på att du vill radera tavla {title}? Detta kommer att radera all information från denna tavla.",
     "Delete the board?" : "Radera tavlan?",
-    "Delete board" : "Ta bort tavla",
-    "Board details" : "Taveldetaljer",
     "Link to a board" : "Länka till en tavla",
     "Link to a card" : "Länka till ett kort",
     "Something went wrong" : "Något gick fel",
