@@ -13,12 +13,13 @@ OC.L10N.register(
     "Can share" : "Can share",
     "Delete" : "நீக்குக",
     "Edit" : "தொகுக்க",
+    "Title" : "தலைப்பு",
     "Description" : "விவரிப்பு",
     "Modified" : "மாற்றப்பட்டது",
     "Save" : "சேமிக்க ",
     "Update" : "இற்றைப்படுத்தல்",
     "seconds ago" : "செக்கன்களுக்கு முன்",
-    "Settings" : "அமைப்புகள்",
-    "Share" : "பகிர்வு"
+    "Shared with you" : "Shared with you",
+    "Settings" : "அமைப்புகள்"
 },
 "nplurals=2; plural=(n != 1);");
