@@ -58,6 +58,8 @@ OC.L10N.register(
     "Add card" : "Thêm tác vụ",
     "Add a new card" : "Thêm một tác vụ mới",
     "Edit" : "Chỉnh sửa",
+    "Title" : "Tên",
+    "Members" : "Thành viên",
     "Due date" : "Thời hạn",
     "Remove due date" : "Xóa thời hạn",
     "Description" : "Mô tả",
@@ -74,16 +76,12 @@ OC.L10N.register(
     "seconds ago" : "vài giây trước",
     "Assign to me" : "Phân công cho tôi",
     "Archived boards" : "Dự án đã lưu trữ",
-    "Shared boards" : "Chia sẽ dự án",
+    "Shared with you" : "Đã chia sẻ với bạn",
     "Settings" : "Thiết lập",
     "New board title" : "Tên dự án mới",
-    "Share" : "Chia sẻ",
     "Edit board" : "Chỉnh sửa dự án",
-    "An error occurred" : "Có lỗi đã xảy ra",
-    "Archive board" : "Lưu trữ dự án",
-    "Unarchive board" : "Bỏ lưu trữ dự án",
-    "Delete board" : "Xóa dự án",
     "Board details" : "Thông tin dự án",
+    "An error occurred" : "Có lỗi đã xảy ra",
     "Maximum file size of {size} exceeded" : "Đã vượt quá kích thước {size} tối đa tập tin"
 },
 "nplurals=1; plural=0;");
