@@ -177,25 +177,21 @@ OC.L10N.register(
     "(group)" : "（组）",
     "seconds ago" : "几秒前",
     "Assign to me" : "指派给我",
+    "Unarchive card" : "恢复卡片存档",
+    "Archive card" : "归档卡片",
     "Delete card" : "删除卡片",
     "Move card" : "移动卡片",
     "Card details" : "卡片详情",
     "Select a stack" : "选择一个任务",
     "All boards" : "全部面板",
     "Archived boards" : "已归档面板",
-    "Shared boards" : "已共享面板",
-    "Settings" : "设置",
+    "Shared with you" : "收到的共享",
     "Limiting Deck will block users not part of those groups from creating their own boards. Users will still be able to work on boards that have been shared with them." : "非面板创建用户组的用户将不能使用受限看板。但用户仍然能够使用已共享给他们的面板工作。",
+    "Settings" : "设置",
     "New board title" : "新面板标题",
-    "Share" : "共享",
-    "Options" : "选项",
     "Edit board" : "编辑面板",
-    "An error occurred" : "发生错误",
-    "Clone board" : "克隆面板",
-    "Archive board" : "归档面板",
-    "Unarchive board" : "未归档面板",
-    "Delete board" : "删除面板",
     "Board details" : "面板详情",
+    "An error occurred" : "发生错误",
     "Link to a board" : "链接到一个面板",
     "Link to a card" : "链接到一张卡片",
     "Something went wrong" : "有地方出错了",
