@@ -15,7 +15,7 @@ OC.L10N.register(
     "Reply" : "回覆",
     "Update" : "更新",
     "seconds ago" : "秒前",
-    "Settings" : "設定",
-    "Share" : "分享"
+    "Shared with you" : "Shared with you",
+    "Settings" : "設定"
 },
 "nplurals=1; plural=0;");
